@@ -7,10 +7,10 @@ public:
     Window();
 };
 
-#include <QtCore/QDir>
+#include <QDir>
 
 #include <kde_terminal_interface.h>
-#include <kparts/part.h>
+#include <kparts/readonlypart.h>
 #include <kservice.h>
 #include <QApplication>
 
@@ -18,7 +18,7 @@ Window::Window()
 {
     this->resize(800, 600);
 
-    KService::Ptr service = KService::serviceByDesktopName("konsolepart");
+    KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("konsolepart"));
     Q_ASSERT(service);
 
     KParts::ReadOnlyPart *part = service->createInstance<KParts::ReadOnlyPart>(this, this, QVariantList());
@@ -34,11 +34,11 @@ Window::Window()
 
 int main(int argc, char **argv)
 {
-    QApplication::setApplicationName("tetest");
+    QApplication::setApplicationName(QStringLiteral("tetest"));
     QApplication app(argc, argv);
     Window *window = new Window();
     window->show();
     return app.exec();
-};
+}
 
 #include "terminal_test.moc"
